==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance.md <==
# AmazonEc2M5ZnInstance


```text
aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance
```

```text
include('aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance')
```



| Illustration | AmazonEc2M5ZnInstance | AmazonEc2M5ZnInstanceCard | AmazonEc2M5ZnInstanceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance.png) | ![illustration for AmazonEc2M5ZnInstance](../../../aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance.Local.png) | ![illustration for AmazonEc2M5ZnInstanceCard](../../../aws-20210730/Resource/Compute/AmazonEc2M5ZnInstanceCard.Local.png) | ![illustration for AmazonEc2M5ZnInstanceGroup](../../../aws-20210730/Resource/Compute/AmazonEc2M5ZnInstanceGroup.Local.png) |




## AmazonEc2M5ZnInstance

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5ZnInstance
include('aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance')

' renders the element
AmazonEc2M5ZnInstance('AmazonEc2M5ZnInstance', 'Amazon Ec2 M5 Zn Instance', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5ZnInstance
include('aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance')

' renders the element
AmazonEc2M5ZnInstance('AmazonEc2M5ZnInstance', 'Amazon Ec2 M5 Zn Instance', 'an optional tech label')
@enduml
```

## AmazonEc2M5ZnInstanceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5ZnInstanceCard
include('aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance')

' renders the element
AmazonEc2M5ZnInstanceCard('AmazonEc2M5ZnInstanceCard', 'Amazon Ec2 M5 Zn Instance Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5ZnInstanceCard
include('aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance')

' renders the element
AmazonEc2M5ZnInstanceCard('AmazonEc2M5ZnInstanceCard', 'Amazon Ec2 M5 Zn Instance Card', 'an optional description')
@enduml
```

## AmazonEc2M5ZnInstanceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5ZnInstanceGroup
include('aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance')

' renders the element
AmazonEc2M5ZnInstanceGroup('AmazonEc2M5ZnInstanceGroup', 'Amazon Ec2 M5 Zn Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5ZnInstanceGroup
include('aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance')

' renders the element
AmazonEc2M5ZnInstanceGroup('AmazonEc2M5ZnInstanceGroup', 'Amazon Ec2 M5 Zn Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance.md <==
# AmazonEc2M5ZnInstance


```text
aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance
```

```text
include('aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance')
```



| Illustration | AmazonEc2M5ZnInstance | AmazonEc2M5ZnInstanceCard | AmazonEc2M5ZnInstanceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance.png) | ![illustration for AmazonEc2M5ZnInstance](../../../aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance.Local.png) | ![illustration for AmazonEc2M5ZnInstanceCard](../../../aws-20210730/Resource/Compute/AmazonEc2M5ZnInstanceCard.Local.png) | ![illustration for AmazonEc2M5ZnInstanceGroup](../../../aws-20210730/Resource/Compute/AmazonEc2M5ZnInstanceGroup.Local.png) |




## AmazonEc2M5ZnInstance

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5ZnInstance
include('aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance')

' renders the element
AmazonEc2M5ZnInstance('AmazonEc2M5ZnInstance', 'Amazon Ec2 M5 Zn Instance', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5ZnInstance
include('aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance')

' renders the element
AmazonEc2M5ZnInstance('AmazonEc2M5ZnInstance', 'Amazon Ec2 M5 Zn Instance', 'an optional tech label')
@enduml
```

## AmazonEc2M5ZnInstanceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5ZnInstanceCard
include('aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance')

' renders the element
AmazonEc2M5ZnInstanceCard('AmazonEc2M5ZnInstanceCard', 'Amazon Ec2 M5 Zn Instance Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5ZnInstanceCard
include('aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance')

' renders the element
AmazonEc2M5ZnInstanceCard('AmazonEc2M5ZnInstanceCard', 'Amazon Ec2 M5 Zn Instance Card', 'an optional description')
@enduml
```

## AmazonEc2M5ZnInstanceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5ZnInstanceGroup
include('aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance')

' renders the element
AmazonEc2M5ZnInstanceGroup('AmazonEc2M5ZnInstanceGroup', 'Amazon Ec2 M5 Zn Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2M5ZnInstanceGroup
include('aws-20210730/Resource/Compute/AmazonEc2M5ZnInstance')

' renders the element
AmazonEc2M5ZnInstanceGroup('AmazonEc2M5ZnInstanceGroup', 'Amazon Ec2 M5 Zn Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
